class RateLimitedException(Exception):pass
class BadRequestException(Exception):pass
class ServerErrorException(Exception):pass